@@ -20,8 +20,8 @@ def read_args():
     parser = argparse.ArgumentParser(description= 'The FairDynamicRec tool for running recommender systems experiments in dynamic setting.', epilog='For documentation, refer to: ')
 
     # todo remove py-eval AS
-    parser.add_argument('action', choices=['run', 'split', 'eval', 'rerank', 'post', 'purge', 'status', 'describe', 'check', 'py-eval'], nargs='?')
-    # parser.add_argument('action', choices=['run', 'split', 'eval', 'rerank', 'post', 'purge', 'status', 'describe', 'check', 'py-eval'])
+    # parser.add_argument('action', choices=['run', 'split', 'eval', 'rerank', 'post', 'purge', 'status', 'describe', 'check', 'py-eval'], nargs='?')
+    parser.add_argument('action', choices=['run', 'split', 'eval', 'rerank', 'post', 'purge', 'status', 'describe', 'check', 'py-eval'])
 
     parser.add_argument("-t", "--target", help="Path to experiment directory")#, default='demo01')
 
@@ -52,8 +52,8 @@ if __name__ == '__main__':
     print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": Running experiment.")
 
     args = read_args()
-    args['action'] = 'run'
-    args['target'] = '/Users/m.mansouryuva.nl/Research/FairDynamicRec/study'
+    # args['action'] = 'run'
+    # args['target'] = '/Users/m.mansouryuva.nl/Research/FairDynamicRec/study'
 
     # purge_old_logs(args['target'] + "/*")
     log_name = create_log_name('FairDynamicRec_log{}.log')
