@@ -99,6 +99,15 @@ class ConfigCmd:
     def get_supplier_data_delimiter(self):
         return str.encode(self._xml_input.findall('data/supplier-file')[0].attrib['delimiter']).decode("unicode_escape")
 
+    def get_rating_data_size(self):
+        n_rows, n_cols = None, None
+        if self._xml_input.findall('data/rating-file'):
+            if 'n-rows' in self._xml_input.findall('data/rating-file')[0].attrib:
+                n_rows = int(self._xml_input.findall('data/rating-file')[0].attrib['n-rows'])
+            if 'n-cols' in self._xml_input.findall('data/rating-file')[0].attrib:
+                n_cols = int(self._xml_input.findall('data/rating-file')[0].attrib['n-cols'])
+        return n_rows, n_cols
+
     def get_item_data_category_column(self):
         return int(self._xml_input.findall('data/item-file')[0].attrib['category_column'])
     def get_item_data_category_delimiter(self):
