@@ -44,16 +44,19 @@ class EAHybridLSBLinUCB(EALSB):
             user = batch_users[i]
             _clicks, _batch_features = self.__collect_feedback(clicks, i)
 
-            discount_coef = [pow(self.gamma, i) for i in range(1, len(_clicks) + 1)]
-            #1
+            discount_coef = [pow(self.gamma, j) for j in range(1, len(_clicks) + 1)]
+            # 1
             # discount_coef_reward = [1 + pow(self.gamma, len(rankings[i])-j+1) for j in range(1, len(_clicks) + 1)]
             # discount_coef_penalization = [x+1 for x in discount_coef]
-            #2
+            # 2
             # discount_coef_reward = [pow(self.gamma, len(rankings[i]) - j + 1) for j in range(1, len(_clicks) + 1)]
             # discount_coef_penalization = [x for x in discount_coef]
-            #3
-            discount_coef_reward = [pow(self.gamma, len(rankings[i]) - j + 1) for j in range(1, len(_clicks) + 1)]
-            discount_coef_penalization = [pow(1 - self.gamma, j) for j in range(1, len(_clicks) + 1)]
+            # 3
+            # discount_coef_reward = [pow(self.gamma, len(rankings[i]) - j + 1) for j in range(1, len(_clicks) + 1)]
+            # discount_coef_penalization = [pow(1 - self.gamma, j) for j in range(1, len(_clicks) + 1)]
+            # 4
+            discount_coef_reward = [1 + pow(self.gamma, len(rankings[i]) - j + 1) for j in range(1, len(_clicks) + 1)]
+            # discount_coef_penalization = [pow(1 - self.gamma, j) for j in range(1, len(_clicks) + 1)]
 
             if self.type == 'item_weight':
                 clicked_items_index = np.where(_clicks == 1)[0]
@@ -89,16 +92,17 @@ class EAHybridLSBLinUCB(EALSB):
             if self.type == 'feature_weight':
                 clicked_items_index = np.where(_clicks == 1)[0]
                 _x = x
-                if len(clicked_items_index) == 0:
-                    _x = -np.multiply(np.array(discount_coef_penalization).reshape(len(_clicks), 1), _x)
-                else:
-                    previous_clicked_item_index = 0
-                    for clicked_item_index in clicked_items_index:
-                        current_clicked_item_index = clicked_item_index
-                        _x[current_clicked_item_index, :] = discount_coef_reward[current_clicked_item_index] * _x[current_clicked_item_index, :]
-                        _x[previous_clicked_item_index: current_clicked_item_index, :] = -np.multiply(np.array(discount_coef_penalization[previous_clicked_item_index: current_clicked_item_index]).reshape(current_clicked_item_index-previous_clicked_item_index,1), _x[previous_clicked_item_index: current_clicked_item_index, :])
-                        previous_clicked_item_index = current_clicked_item_index + 1
-                self.b_x[user] += _x.sum(axis=0)
+                # if len(clicked_items_index) == 0:
+                #     _x = -np.multiply(np.array(discount_coef_penalization).reshape(len(_clicks), 1), _x)
+                # else:
+                # previous_clicked_item_index = 0
+                for clicked_item_index in clicked_items_index:
+                    current_clicked_item_index = clicked_item_index
+                    _x[current_clicked_item_index, :] = discount_coef_reward[current_clicked_item_index] * _x[current_clicked_item_index, :]
+                    # _x[previous_clicked_item_index: current_clicked_item_index, :] = -np.multiply(np.array(discount_coef_penalization[previous_clicked_item_index: current_clicked_item_index]).reshape(current_clicked_item_index-previous_clicked_item_index,1), _x[previous_clicked_item_index: current_clicked_item_index, :])
+                    # previous_clicked_item_index = current_clicked_item_index + 1
+                # self.b_x[user] += _x.sum(axis=0)
+                self.b_x[user] += np.dot(_clicks, _x)
             else:
                 self.b_x[user] += np.dot(_clicks, x)
 
@@ -112,16 +116,17 @@ class EAHybridLSBLinUCB(EALSB):
             if self.type == 'feature_weight':
                 clicked_items_index = np.where(_clicks == 1)[0]
                 _z = z
-                if len(clicked_items_index) == 0:
-                    _z = -np.multiply(np.array(discount_coef_penalization).reshape(len(_clicks), 1), _z)
-                else:
-                    previous_clicked_item_index = 0
-                    for clicked_item_index in clicked_items_index:
-                        current_clicked_item_index = clicked_item_index
-                        _z[current_clicked_item_index, :] = discount_coef_reward[current_clicked_item_index] * _z[current_clicked_item_index, :]
-                        _z[previous_clicked_item_index: current_clicked_item_index, :] = -np.multiply(np.array(discount_coef_penalization[previous_clicked_item_index: current_clicked_item_index]).reshape(current_clicked_item_index-previous_clicked_item_index,1), _z[previous_clicked_item_index: current_clicked_item_index, :])
-                        previous_clicked_item_index = current_clicked_item_index + 1
-                self.b_z[user] += _z.sum(axis=0) - np.dot(BA, self.b_x[user])
+                # if len(clicked_items_index) == 0:
+                #     _z = -np.multiply(np.array(discount_coef_penalization).reshape(len(_clicks), 1), _z)
+                # else:
+                # previous_clicked_item_index = 0
+                for clicked_item_index in clicked_items_index:
+                    current_clicked_item_index = clicked_item_index
+                    _z[current_clicked_item_index, :] = discount_coef_reward[current_clicked_item_index] * _z[current_clicked_item_index, :]
+                    # _z[previous_clicked_item_index: current_clicked_item_index, :] = -np.multiply(np.array(discount_coef_penalization[previous_clicked_item_index: current_clicked_item_index]).reshape(current_clicked_item_index-previous_clicked_item_index,1), _z[previous_clicked_item_index: current_clicked_item_index, :])
+                    # previous_clicked_item_index = current_clicked_item_index + 1
+                # self.b_z[user] += _z.sum(axis=0) - np.dot(BA, self.b_x[user])
+                self.b_z[user] += np.dot(_clicks, _z) - np.dot(BA, self.b_x[user])
             else:
                 self.b_z[user] += np.dot(_clicks, z) - np.dot(BA, self.b_x[user])
 
