@@ -82,7 +82,7 @@ class EALSB(AbstractRanker):
             # discount_coef_penalization = [pow(1-self.gamma, j) for j in range(1, len(_clicks) + 1)]
             # 4
             discount_coef_reward = [1 + pow(self.gamma, len(rankings[i]) - j + 1) for j in range(1, len(_clicks) + 1)]
-            discount_coef_penalization = [pow(1 - self.gamma, j) for j in range(1, len(_clicks) + 1)]
+            # discount_coef_penalization = [pow(1 - self.gamma, j) for j in range(1, len(_clicks) + 1)]
 
             if self.type == 'item_weight':
                 clicked_items_index = np.where(_clicks == 1)[0]
@@ -124,18 +124,18 @@ class EALSB(AbstractRanker):
             # for b: feedback
             if self.type == 'feature_weight':
                 clicked_items_index = np.where(_clicks == 1)[0]
-                if len(clicked_items_index) == 0:
-                    _batch_features = -np.multiply(np.array(discount_coef_penalization).reshape(len(_clicks), 1), _batch_features)
-                else:
-                    previous_clicked_item_index = 0
-                    for clicked_item_index in clicked_items_index:
-                        current_clicked_item_index = clicked_item_index
-                        _batch_features[current_clicked_item_index, :] = discount_coef_reward[current_clicked_item_index] * _batch_features[current_clicked_item_index, :]
-                        _batch_features[previous_clicked_item_index: current_clicked_item_index, :] = -np.multiply(np.array(discount_coef_penalization[previous_clicked_item_index: current_clicked_item_index]).reshape(current_clicked_item_index-previous_clicked_item_index,1), _batch_features[previous_clicked_item_index: current_clicked_item_index, :])
-                        previous_clicked_item_index = current_clicked_item_index + 1
-                self.b_tmp[user] = _batch_features.sum(axis=0)
-            else:
-                self.b_tmp[user] = np.dot(_clicks, _batch_features)
+                # if len(clicked_items_index) == 0:
+                #     _batch_features = -np.multiply(np.array(discount_coef_penalization).reshape(len(_clicks), 1), _batch_features)
+                # else:
+                # previous_clicked_item_index = 0
+                for clicked_item_index in clicked_items_index:
+                    current_clicked_item_index = clicked_item_index
+                    _batch_features[current_clicked_item_index, :] = discount_coef_reward[current_clicked_item_index] * _batch_features[current_clicked_item_index, :]
+                    # _batch_features[previous_clicked_item_index: current_clicked_item_index, :] = -np.multiply(np.array(discount_coef_penalization[previous_clicked_item_index: current_clicked_item_index]).reshape(current_clicked_item_index-previous_clicked_item_index,1), _batch_features[previous_clicked_item_index: current_clicked_item_index, :])
+                    # previous_clicked_item_index = current_clicked_item_index + 1
+                # self.b_tmp[user] = _batch_features.sum(axis=0)
+            # else:
+            self.b_tmp[user] = np.dot(_clicks, _batch_features)
             self.b[user] += self.b_tmp[user]
 
             # for parameter theta
